
/* source: http://www.higherpass.com/java/Tutorials/Basic-File-Manipulation-With-Java/
 * Purpose: This program demonstrate how to read a data file using the FileInputStream and BufferedReader classes.
 * 
 * Reading a file involves a few steps.
 * First a File object must be opened, then it must be attached to a FileInputStream and the BufferedReader.
 * File input/output streams and associated objects throw errors and must be caught with try/catch statements.
 */
// compilation command using JDK: javac ReadFileExample.java
// run the program: java ReadFileExample data.txt
//  Note: data.txt is a data file previously created.

import java.io.*;
class FileInputStreamExample {
    public static void main(String args[]) {
        if (args.length != 1) {
            System.out.println("Must specify file on the command line");
            return;
        }

        try {
            FileInputStream fStream = new FileInputStream(args[0]);
            BufferedReader in = new BufferedReader(new InputStreamReader(fStream));
/* http://download.oracle.com/javase/6/docs/api/java/io/BufferedReader.html
 * Without buffering, each invocation of read() or readLine() could cause bytes to be read from the file,
 * converted into characters, and then returned, which can be very inefficient.
 */
            while (in.ready()) {
                System.out.println(in.readLine());
            }
            in.close();
        } catch (IOException e) {
            System.out.println("File input error");
        }
    }
} // class FileInputStreamExample